@@ -7,8 +7,8 @@ def create_lr_instance(C = 1.0, penalty = 'l2', multi_class = 'auto'):
 
     Parameters
     ----------
-    penalty : {l1, l2, elasticnet, none}
+    penalty : {‘l1’, ‘l2’, ‘elasticnet’, ‘none’}
     C : Inverse of regularization strength
-    multi_class : {auto, ovr, multinomial}
+    multi_class : {‘auto’, ‘ovr’, ‘multinomial’}
     '''
     return LogisticRegression(C = C, penalty = penalty, multi_class = multi_class)
\ No newline at end of file
