@@ -159,7 +159,7 @@ class MLP:
     
 
 from sklearn.neural_network import MLPClassifier
-def create_sklearn_mlp_instance(L, activation = 'relu'):
+def create_mlp_instance(L, activation = 'relu'):
     '''
     The above is a self-implementation of MLP. This one reuses the sklearn.neural_network.MLPClassifier.
     
